summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBehdad Esfahbod <behdad@behdad.org>2008-09-22 17:34:36 -0400
committerBehdad Esfahbod <behdad@behdad.org>2008-09-22 17:34:36 -0400
commit23b9767bb3b35995099ae9c7b3d84f18e7a76dcc (patch)
tree226c597e7b6bde7dca14505176888b3507e6fbaa
parent20be3182ef29bb07ffac749f5cf1844b4781e1bb (diff)
Rename Makefile.*.config to Makefile.*.features as they should not be modified
The .config naming was giving people the impression that they can modify it. That's not the case.
-rwxr-xr-xautogen.sh6
-rw-r--r--boilerplate/Makefile.am2
-rw-r--r--build/aclocal.makefile.m410
-rw-r--r--doc/public/Makefile.am2
-rw-r--r--src/Makefile.am2
5 files changed, 11 insertions, 11 deletions
diff --git a/boilerplate/Makefile.am b/boilerplate/Makefile.am
index 22f66a89d..80e3e6ddc 100644
--- a/boilerplate/Makefile.am
+++ b/boilerplate/Makefile.am
@@ -1,7 +1,7 @@
# Note: All source files are listed in Makefile.sources.
include $(top_srcdir)/build/Makefile.am.common
-include $(srcdir)/Makefile.am.config
+include $(srcdir)/Makefile.am.features
AM_CPPFLAGS = \
-I$(srcdir) \
diff --git a/build/aclocal.makefile.m4 b/build/aclocal.makefile.m4
index 1602a32a0..f6febde5f 100644
--- a/build/aclocal.makefile.m4
+++ b/build/aclocal.makefile.m4
@@ -1,6 +1,6 @@
dnl
-dnl These are the facilities for generating Makefile.am.config and
-dnl Makefile.win32.config files.
+dnl These are the facilities for generating Makefile.am.features and
+dnl Makefile.win32.features files.
dnl
dnl
@@ -72,7 +72,7 @@ m4_define([_CAIRO_MAKEFILES])dnl
dnl
dnl CAIRO_CONFIG_MAKEFILE(TAG, DIR)
dnl
-dnl Create DIR/Makefile.*.config files
+dnl Create DIR/Makefile.*.features files
dnl TAG is a TAG used by other CAIRO_MAKEFILE_* macros to append to these
dnl Makefile's.
dnl
@@ -89,10 +89,10 @@ AC_DEFUN([CAIRO_CONFIG_MAKEFILE],
CAIRO_ACCUMULATORS_REGISTER(MAKEFILE_$1_WIN32, m4_newline, [# Generated by configure. Do not edit.]m4_newline[include Makefile.sources]m4_newline)dnl
dnl Generate
- CAIRO_CONFIG_COMMANDS([$srcdir/$2/Makefile.am.config],
+ CAIRO_CONFIG_COMMANDS([$srcdir/$2/Makefile.am.features],
[echo "$CAIRO_MAKEFILE_$1_AMAKE"],
[CAIRO_MAKEFILE_$1_AMAKE='$CAIRO_MAKEFILE_$1_AMAKE'])dnl
- CAIRO_CONFIG_COMMANDS([$srcdir/$2/Makefile.win32.config],
+ CAIRO_CONFIG_COMMANDS([$srcdir/$2/Makefile.win32.features],
[echo "$CAIRO_MAKEFILE_$1_WIN32"],
[CAIRO_MAKEFILE_$1_WIN32='$CAIRO_MAKEFILE_$1_WIN32'])dnl
])dnl
diff --git a/doc/public/Makefile.am b/doc/public/Makefile.am
index b4db8b765..00ab27db1 100644
--- a/doc/public/Makefile.am
+++ b/doc/public/Makefile.am
@@ -1,5 +1,5 @@
include $(top_srcdir)/build/Makefile.am.common
-include $(top_srcdir)/src/Makefile.am.config
+include $(top_srcdir)/src/Makefile.am.features
# The name of the module.
DOC_MODULE=cairo
diff --git a/src/Makefile.am b/src/Makefile.am
index 4b6d86b56..ebe501f71 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,7 +1,7 @@
# Note: All source files are listed in Makefile.sources.
include $(top_srcdir)/build/Makefile.am.common
-include $(srcdir)/Makefile.am.config
+include $(srcdir)/Makefile.am.features
AM_CPPFLAGS = -I$(srcdir) $(CAIRO_CFLAGS)
diff --git a/autogen.sh b/autogen.sh
index f3170ba9e..7fd76056d 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -169,9 +169,9 @@ do_cmd $ACLOCAL $ACLOCAL_FLAGS
do_cmd $AUTOHEADER
-# create dummy */Makefile.am.config and ChangeLog to make automake happy
-> boilerplate/Makefile.am.config
-> src/Makefile.am.config
+# create dummy */Makefile.am.features and ChangeLog to make automake happy
+> boilerplate/Makefile.am.features
+> src/Makefile.am.features
touch ChangeLog
# We don't call gtkdocize right now. When we do, we should then modify